@@ -2,6 +2,6 @@ from .theme import Theme
 
 __all__ = ["Theme"]
 
-__author__ = "IreTheKID"
-__version__ = "0.1.7"
+__author__ = "frissyn"
+__version__ = "0.2.0"
 __doc__ = "Python package for creating IDE themes on Repl.it"
